@@ -1,4 +1,4 @@
 from .data_clusterization import similar_nodes, cluster_generation, clusters_detection, low_limit_network
-from .data_management import load_model, draw_community, nx_to_Graph, labels_modifier
+from .data_management import load_model, draw_community, nx_to_Graph, labels_modifier, summary_edgelist, summary_clusters
 from .data_edgelists import generate_edgelist, edgelist_from_csv, complete_edgelist, stellar_edgelist
 from .data_manipulation import best_line_projection, recover_points
