@@ -80,8 +80,8 @@ def cluster_generation(result, cluster_rigidity = 0.7):
     positions = np.where(np.array(result[1]) >= cluster_rigidity)
     return(cluster[positions])
   
-def similar_nodes(G, node=1, picked=10, Epochs = 30, Weight=False, save_model = False,
-                  model_name = 'model.wordvectors', graph = None, **kwargs):
+def similar_nodes(G, node=1, picked=10, Epochs = 30, Weight=False, model_name = 'model.wordvectors',
+                  graph = None, **kwargs):
     """
     Description
     -----------
@@ -169,7 +169,7 @@ def similar_nodes(G, node=1, picked=10, Epochs = 30, Weight=False, save_model =
     else:
         n2v = Node2Vec(graph, **kwargs)
     n2v.train(epochs = Epochs, progress_bar=False)
-    if save_model == True:
+    if model_name != None:
         n2v.save(model_name)
     nodes = n2v.wv.most_similar(node, topn = picked)
     nodes_id = list(list(zip(*nodes))[0])
@@ -240,6 +240,7 @@ def clusters_detection(G, cluster_rigidity=0.7, spacing=5, dim_fraction=0.8, **k
         flag = True
         nodes, similarities = similar_nodes(G, node_id, **kwargs)
         current_cluster = cluster_generation([nodes, similarities], cluster_rigidity) # TESTING THIS OBJECT.
+        current_cluster = np.append(current_cluster, node_id) # Add current node to current_cluster
         dimension = np.size(current_cluster)
         different_nodes_counters = [] # This is used to find the cluster to expand and to decide whether to create a new cluster.
         if len(clusters) != 0:
@@ -250,10 +251,8 @@ def clusters_detection(G, cluster_rigidity=0.7, spacing=5, dim_fraction=0.8, **k
                 current_cluster = current_cluster[~np.in1d(current_cluster,previous_cluster)] # current_cluster filtering.
         if dimension == np.size(current_cluster):
             # Creating new cluster if the dimension of cluster remain the same. This means that the nodes in common are none.
-            if dimension == 0: # Stop only if the first cluster is empty.
-                if index == 0: raise Exception("Error: The dimension of the cluster is 0. Try to reduce cluster_rigidity.")
-                else:
-                    warnings.warn("Warning: The dimension of the cluster is 0. You may want to reduce cluster_rigidity.",RuntimeWarning)
+            if dimension == 1: # If the current cluster is empty, skip the process. (empty means with only current node)
+                    warnings.warn("Warning: The dimension of the cluster is 0. You may want to reduce cluster_rigidity.", RuntimeWarning)
                     flag = False
             if flag == True:
                 print("- Creating new cluster")
@@ -276,12 +275,4 @@ def clusters_detection(G, cluster_rigidity=0.7, spacing=5, dim_fraction=0.8, **k
             pass
     tot_nodes = [val for sublist in clusters for val in sublist]  # Flatten list of lists
     unlabeled = list(set(np.array(list(G.nodes)).astype(str)) - set(tot_nodes))  # Get remaining nodes
-    print('\033[1m' + '--------- Clusters Information ---------')
-    print('- Number of Clusters: ', index)
-    print('- Total nodes: ', len(tot_nodes) + len(unlabeled))
-    print('- Clustered nodes: ', len(tot_nodes))
-    print('- Number of unlabeled nodes: ', len(unlabeled))
-    for i in range(0,len(clusters)):
-        print(f"- Nodes in cluster {i+1}:", clusters[i].size)
     return clusters, unlabeled
-  
