@@ -15,7 +15,11 @@ def generate_edgelist(df):
     ----------
     df : pandas.DataFrame
         Pandas DataFrame edge list of the wanted network.
-        
+    
+    Raises
+    ------
+    ValueError : An error is raised if the values of the DataFrame headers is not the required one.
+    
     Returns
     -------
     output : list
@@ -39,7 +43,7 @@ def generate_edgelist(df):
     # Check header:
     header_names = list(df.columns.values)
     if header_names[0] != 'node1' or header_names[1] != 'node2' or header_names[2] != 'weight':
-        raise TypeError('The header format is different from the required one.')
+        raise ValueError('The header format is different from the required one.')
     # Forcing values type
     df = df.astype({'node1': str, 'node2': str, 'weight': np.float64})
     return list(df.itertuples(index = False, name = None))
@@ -57,6 +61,10 @@ def edgelist_from_csv(path, **kwargs):
         Path or name of the .csv file to be loaded.
     **kwargs :  pandas.read_csv() arguments
     
+    Raises
+    ------
+    ValueError : An error is raised if the values of the DataFrame headers is not the required one.
+    
     Returns
     -------
     output : list
@@ -79,10 +87,10 @@ def edgelist_from_csv(path, **kwargs):
     # Check header:
     header_names = list(df_csv.columns.values)
     if header_names[0] != 'node1' or header_names[1] != 'node2' or header_names[2] != 'weight':
-        raise TypeError('The header format is different from the required one.')
+        raise ValueError('The header format is different from the required one.')
     return list(df_csv.itertuples(index = False, name = None))
 
-def complete_edgelist(Z, metric='euclidean', stretch=1., info=False, **kwargs):
+def complete_edgelist(Z, metric='euclidean', **kwargs):
     """
     Description
     -----------
@@ -97,11 +105,6 @@ def complete_edgelist(Z, metric='euclidean', stretch=1., info=False, **kwargs):
     metric : string, optional
         Specifies the metric in which the dataset Z is defined. The metric will determine the values of the weights
         between the links.
-    stretch : float, optional
-        Enlarges the distance between different points exponentially.
-        The default value is '1.0'.
-    info :  bool
-        Flag to print out some generic information of the dataset.
         
     Returns
     -------
@@ -125,27 +128,18 @@ def complete_edgelist(Z, metric='euclidean', stretch=1., info=False, **kwargs):
         7     2     1  0.834821
         8     2     2  1.000000
     """
-    dimension = Z[0].size  # Number of coordinates per point
-    NPoints = Z[:, 0].size  # Number of points
-    weights = stretch*np.exp(-stretch*distance.cdist(Z, Z, metric))  # Distance between all points
+    dimension = Z[0].size # Number of coordinates per point
+    NPoints = Z[:, 0].size # Number of points
+    weights = np.exp(-distance.cdist(Z, Z, metric)) # Distance between all points
+    np.fill_diagonal(weights, 0) # Zero weight on self loops
     weights = weights.flatten() # Weights coulumn
     nodes_id = np.arange(NPoints).astype(str)
     node1 = np.repeat(nodes_id,NPoints)
     node2 = np.tile(nodes_id,NPoints)
     df = pd.DataFrame({'node1': node1, 'node2': node2, 'weight': weights}, **kwargs)
-    if info == True:
-        print('\033[1m' + '--------- General Information ---------')
-        print('Edge list of a fully connected network.')
-        print('The weights are calculated using minus the exponential of the norm defined by the chosen metric.\n')
-        print('- Space dimensionality: ', dimension)
-        print('- Number of Points: ', NPoints)
-        print('- Minimum weight: ', np.min(weights))
-        print('- Maximum weight: ', np.max(weights))
-        print('- Average weight: ', np.mean(weights))
-        print('- Weight Variance: ', np.var(weights))
     return df
 
-def stellar_edgelist(Z, info=False, **kwargs):
+def stellar_edgelist(Z, **kwargs):
     """
     Description
     -----------
@@ -157,8 +151,6 @@ def stellar_edgelist(Z, info=False, **kwargs):
     Z : numpy ndarray
         Numpy array containing as columns the i-th coordinate of the k-th point. The rows are the points, the columns
         are the coordinates.
-    info :  bool
-        Flag to print out some generic information of the dataset.
         
     Returns
     -------
@@ -201,15 +193,5 @@ def stellar_edgelist(Z, info=False, **kwargs):
     weights = np.exp(-np.linalg.norm(Z, axis = 1))
     node2 = np.arange(NPoints).astype(str)
     df = pd.DataFrame({'node1': 'origin', 'node2': node2, 'weight': weights}, **kwargs)
-    if info == True:
-        print('\033[1m' + '--------- General Information ---------')
-        print('Edge list of a stellar network.')
-        print('The weights are calculated using minus the exponential of the euclidean norm.\n')
-        print('- Space dimensionality: ', dimension)
-        print('- Number of Points: ', NPoints)
-        print('- Minimum weight: ', np.min(weights))
-        print('- Maximum weight: ', np.max(weights))
-        print('- Average weight: ', np.mean(weights))
-        print('- Weight Variance: ', np.var(weights))
     return df
   
